Hello community,

here is the log from the commit of package aespipe for openSUSE:Factory checked 
in at 2017-11-07 10:00:45
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Comparing /work/SRC/openSUSE:Factory/aespipe (Old)
 and      /work/SRC/openSUSE:Factory/.aespipe.new (New)
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

Package is "aespipe"

Tue Nov  7 10:00:45 2017 rev:11 rq:539110 version:2.4e

Changes:
--------
--- /work/SRC/openSUSE:Factory/aespipe/aespipe.changes  2017-06-12 
15:28:56.669870005 +0200
+++ /work/SRC/openSUSE:Factory/.aespipe.new/aespipe.changes     2017-11-07 
10:01:30.294668956 +0100
@@ -1,0 +2,7 @@
+Sat Nov  4 22:19:07 UTC 2017 - aavind...@gmail.com
+
+- Update to 2.4e
+  * Added workaround for gpg 2 pinentry-mode bug.
+- Cleanup spec file with spec-cleaner
+
+-------------------------------------------------------------------

Old:
----
  aespipe-v2.4d.tar.bz2

New:
----
  aespipe-2.4e.tar.bz2

++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

Other differences:
------------------
++++++ aespipe.spec ++++++
--- /var/tmp/diff_new_pack.zQSH06/_old  2017-11-07 10:01:32.994571001 +0100
+++ /var/tmp/diff_new_pack.zQSH06/_new  2017-11-07 10:01:32.998570857 +0100
@@ -17,17 +17,17 @@
 
 
 Name:           aespipe
-Version:        2.4d
+Version:        2.4e
 Release:        0
 Summary:        AES Encrypting/Decrypting Pipe
 License:        GPL-2.0
 Group:          Productivity/Security
 Url:            http://loop-aes.sourceforge.net/
-Source:         
http://loop-aes.sourceforge.net/aespipe/aespipe-v%{version}.tar.bz2
-#!BuildIgnore: gcc-PIE
+Source:         
http://loop-aes.sourceforge.net/aespipe/%{name}-v%{version}.tar.bz2#/%{name}-%{version}.tar.bz2
 BuildRequires:  autoconf
 BuildRequires:  automake
 BuildRequires:  gpg2
+#!BuildIgnore:  gcc-PIE
 Requires:       gpg2
 
 %description
@@ -61,7 +61,6 @@
   %{buildroot}%{_bindir}/bz2aespipe
 
 %files
-%defattr(-,root,root)
 %doc ChangeLog README
 %{_bindir}/aespipe
 %{_bindir}/bz2aespipe

++++++ aespipe-v2.4d.tar.bz2 -> aespipe-2.4e.tar.bz2 ++++++
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/aespipe-v2.4d/ChangeLog new/aespipe-v2.4e/ChangeLog
--- old/aespipe-v2.4d/ChangeLog 2015-05-24 09:21:06.000000000 +0200
+++ new/aespipe-v2.4e/ChangeLog 2017-09-10 14:30:46.000000000 +0200
@@ -104,3 +104,6 @@
 aespipe-v2.4d     May 24 2015
     - Fixed endianness bug on little-endian PowerPC. More common big-endian
       PowerPC was OK. Bug reported by Fernando Seiti Furusato.
+
+aespipe-v2.4e     September 10 2017
+    - Added workaround for gpg 2 pinentry-mode bug.
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/aespipe-v2.4d/README new/aespipe-v2.4e/README
--- old/aespipe-v2.4d/README    2015-05-24 09:21:06.000000000 +0200
+++ new/aespipe-v2.4e/README    2017-09-10 14:30:46.000000000 +0200
@@ -1,6 +1,6 @@
-Written by Jari Ruusu <jariru...@users.sourceforge.net>, May 24 2015
+Written by Jari Ruusu <jariru...@users.sourceforge.net>, September 10 2017
 
-Copyright 2002-2015 by Jari Ruusu.
+Copyright 2002-2017 by Jari Ruusu.
 Redistribution of this file is permitted under the GNU Public License.
 
 
@@ -70,7 +70,12 @@
 found.
 
 If you want to use special compiler and/or linker flags, ./configure script
-understands exported CFLAGS= and LDFLAGS= environment variables.
+understands exported CFLAGS= and LDFLAGS= environment variables. In cases
+where compiler/linker produces position independent executable (PIE) by
+default and you want to use assembler optimized code, the PIE thingy needs
+to be disabled like this:
+
+    CFLAGS="-O2 -Wall -fno-pie" LDFLAGS="-no-pie" ./configure
 
 Above installs aespipe program to /usr/local/bin/ directory and man page to
 /usr/local/man/man1/ directory. If you want aespipe program installed in
@@ -78,6 +83,14 @@
 "--bindir=/usr/bin" and "--mandir=/usr/share/man" parameters to ./configure
 script.
 
+When aespipe uses gpg version 2 to decrypt public-key encrypted key file,
+gpg needs special bug workaround. gpg version 1 does not need that
+workaround, and that workaround is not compatible with gpg version 1.
+configure script detects the need for this gpg bug workaround at configure
+time. If you change installed gpg version from 1 to 2, or from 2 to 1, then
+aespipe needs to be configured and compiled again to enable/disable the
+workaround.
+
 
 3. Examples
 ~~~~~~~~~~~
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/aespipe-v2.4d/configure new/aespipe-v2.4e/configure
--- old/aespipe-v2.4d/configure 2015-05-03 18:52:20.000000000 +0200
+++ new/aespipe-v2.4e/configure 2017-09-10 13:52:14.000000000 +0200
@@ -660,6 +660,7 @@
 docdir
 oldincludedir
 includedir
+runstatedir
 localstatedir
 sharedstatedir
 sysconfdir
@@ -740,6 +741,7 @@
 sysconfdir='${prefix}/etc'
 sharedstatedir='${prefix}/com'
 localstatedir='${prefix}/var'
+runstatedir='${localstatedir}/run'
 includedir='${prefix}/include'
 oldincludedir='/usr/include'
 docdir='${datarootdir}/doc/${PACKAGE_TARNAME}'
@@ -992,6 +994,15 @@
   | -silent | --silent | --silen | --sile | --sil)
     silent=yes ;;
 
+  -runstatedir | --runstatedir | --runstatedi | --runstated \
+  | --runstate | --runstat | --runsta | --runst | --runs \
+  | --run | --ru | --r)
+    ac_prev=runstatedir ;;
+  -runstatedir=* | --runstatedir=* | --runstatedi=* | --runstated=* \
+  | --runstate=* | --runstat=* | --runsta=* | --runst=* | --runs=* \
+  | --run=* | --ru=* | --r=*)
+    runstatedir=$ac_optarg ;;
+
   -sbindir | --sbindir | --sbindi | --sbind | --sbin | --sbi | --sb)
     ac_prev=sbindir ;;
   -sbindir=* | --sbindir=* | --sbindi=* | --sbind=* | --sbin=* \
@@ -1129,7 +1140,7 @@
 for ac_var in  exec_prefix prefix bindir sbindir libexecdir datarootdir \
                datadir sysconfdir sharedstatedir localstatedir includedir \
                oldincludedir docdir infodir htmldir dvidir pdfdir psdir \
-               libdir localedir mandir
+               libdir localedir mandir runstatedir
 do
   eval ac_val=\$$ac_var
   # Remove trailing slashes.
@@ -1282,6 +1293,7 @@
   --sysconfdir=DIR        read-only single-machine data [PREFIX/etc]
   --sharedstatedir=DIR    modifiable architecture-independent data [PREFIX/com]
   --localstatedir=DIR     modifiable single-machine data [PREFIX/var]
+  --runstatedir=DIR       modifiable per-process data [LOCALSTATEDIR/run]
   --libdir=DIR            object code libraries [EPREFIX/lib]
   --includedir=DIR        C header files [PREFIX/include]
   --oldincludedir=DIR     C header files for non-gcc [/usr/include]
@@ -3624,7 +3636,7 @@
     We can't simply define LARGE_OFF_T to be 9223372036854775807,
     since some C++ compilers masquerading as C compilers
     incorrectly reject 9223372036854775807.  */
-#define LARGE_OFF_T (((off_t) 1 << 62) - 1 + ((off_t) 1 << 62))
+#define LARGE_OFF_T ((((off_t) 1 << 31) << 31) - 1 + (((off_t) 1 << 31) << 31))
   int off_t_is_large[(LARGE_OFF_T % 2147483629 == 721
                       && LARGE_OFF_T % 2147483647 == 1)
                      ? 1 : -1];
@@ -3670,7 +3682,7 @@
     We can't simply define LARGE_OFF_T to be 9223372036854775807,
     since some C++ compilers masquerading as C compilers
     incorrectly reject 9223372036854775807.  */
-#define LARGE_OFF_T (((off_t) 1 << 62) - 1 + ((off_t) 1 << 62))
+#define LARGE_OFF_T ((((off_t) 1 << 31) << 31) - 1 + (((off_t) 1 << 31) << 31))
   int off_t_is_large[(LARGE_OFF_T % 2147483629 == 721
                       && LARGE_OFF_T % 2147483647 == 1)
                      ? 1 : -1];
@@ -3694,7 +3706,7 @@
     We can't simply define LARGE_OFF_T to be 9223372036854775807,
     since some C++ compilers masquerading as C compilers
     incorrectly reject 9223372036854775807.  */
-#define LARGE_OFF_T (((off_t) 1 << 62) - 1 + ((off_t) 1 << 62))
+#define LARGE_OFF_T ((((off_t) 1 << 31) << 31) - 1 + (((off_t) 1 << 31) << 31))
   int off_t_is_large[(LARGE_OFF_T % 2147483629 == 721
                       && LARGE_OFF_T % 2147483647 == 1)
                      ? 1 : -1];
@@ -3739,7 +3751,7 @@
     We can't simply define LARGE_OFF_T to be 9223372036854775807,
     since some C++ compilers masquerading as C compilers
     incorrectly reject 9223372036854775807.  */
-#define LARGE_OFF_T (((off_t) 1 << 62) - 1 + ((off_t) 1 << 62))
+#define LARGE_OFF_T ((((off_t) 1 << 31) << 31) - 1 + (((off_t) 1 << 31) << 31))
   int off_t_is_large[(LARGE_OFF_T % 2147483629 == 721
                       && LARGE_OFF_T % 2147483647 == 1)
                      ? 1 : -1];
@@ -3763,7 +3775,7 @@
     We can't simply define LARGE_OFF_T to be 9223372036854775807,
     since some C++ compilers masquerading as C compilers
     incorrectly reject 9223372036854775807.  */
-#define LARGE_OFF_T (((off_t) 1 << 62) - 1 + ((off_t) 1 << 62))
+#define LARGE_OFF_T ((((off_t) 1 << 31) << 31) - 1 + (((off_t) 1 << 31) << 31))
   int off_t_is_large[(LARGE_OFF_T % 2147483629 == 721
                       && LARGE_OFF_T % 2147483647 == 1)
                      ? 1 : -1];
@@ -5697,6 +5709,20 @@
 { $as_echo "$as_me:${as_lineno-$LINENO}: result: $x_enable_intelaes" >&5
 $as_echo "$x_enable_intelaes" >&6; }
 
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking if gpg 2 bug workaround can 
be enabled" >&5
+$as_echo_n "checking if gpg 2 bug workaround can be enabled... " >&6; }
+x_gpg2buggy="no"
+if test -n "${GPG_PROG}"; then
+       ${GPG_PROG} --pinentry-mode loopback --version >/dev/null 2>&1
+       if test "$?" = "0"; then
+               x_gpg2buggy="yes"
+               $as_echo "#define GPG2BUGWORKAROUND 1" >>confdefs.h
+
+       fi
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $x_gpg2buggy" >&5
+$as_echo "$x_gpg2buggy" >&6; }
+
 
 ac_config_files="$ac_config_files Makefile"
 
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/aespipe-v2.4d/configure.ac 
new/aespipe-v2.4e/configure.ac
--- old/aespipe-v2.4d/configure.ac      2015-05-03 18:51:42.000000000 +0200
+++ new/aespipe-v2.4e/configure.ac      2017-09-10 13:25:50.000000000 +0200
@@ -1,9 +1,9 @@
 dnl
 dnl  configure.ac
 dnl
-dnl  Written by Jari Ruusu, May 3 2015
+dnl  Written by Jari Ruusu, September 10 2017
 dnl
-dnl  Copyright 2002-2015 by Jari Ruusu.
+dnl  Copyright 2002-2017 by Jari Ruusu.
 dnl  Redistribution of this file is permitted under the GNU Public License.
 dnl
 
@@ -239,6 +239,21 @@
 fi
 AC_MSG_RESULT([$x_enable_intelaes])
 
+dnl  Some gpg 2 versions have buggy handling of --passphrase-fd
+dnl  when the passphrase is used to decrypt public-key encrypted
+dnl  key file. Workaround is to specify --pinentry-mode .
+dnl  gpg 1 versions can not handle this workaround.
+AC_MSG_CHECKING([if gpg 2 bug workaround can be enabled])
+x_gpg2buggy="no"
+if test -n "${GPG_PROG}"; then
+       ${GPG_PROG} --pinentry-mode loopback --version >/dev/null 2>&1
+       if test "$?" = "0"; then
+               x_gpg2buggy="yes"
+               AC_DEFINE([GPG2BUGWORKAROUND], [1])
+       fi
+fi
+AC_MSG_RESULT([$x_gpg2buggy])
+
 AC_SUBST([OPTIMIZED_OBJS])
 AC_CONFIG_FILES([Makefile])
 AC_OUTPUT


Reply via email to
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/aespipe-v2.4d/aespipe.c new/aespipe-v2.4e/aespipe.c
--- old/aespipe-v2.4d/aespipe.c 2015-05-03 18:48:12.000000000 +0200
+++ new/aespipe-v2.4e/aespipe.c 2017-09-10 13:25:50.000000000 +0200
@@ -1,9 +1,9 @@
 /*
  *  aespipe.c
  *
  *  Written by Jari Ruusu, May 3 2015
  *
- *  Copyright 2002-2015 by Jari Ruusu.
+ *  Copyright 2002-2017 by Jari Ruusu.
  *  Redistribution of this file is permitted under the GNU Public License.
  *
  *  AES encrypting or decrypting "pipe", reads from stdin, writes to stdout
@@ -241,6 +241,10 @@
             a[x++] = "--passphrase-fd";
             a[x++] = str;
         }
+#if defined(GPG2BUGWORKAROUND)
+        a[x++] = "--pinentry-mode";     /* gnupg 2 version needs this */
+        a[x++] = "loopback";
+#endif
         a[x++] = "--decrypt";
         a[x] = 0;
 #if defined(PATH_TO_GPG_PROGRAM)
@@ -1177,7 +1181,7 @@
         if(!strcmp(*argv, "-") || (**argv != '-')) {
             usage:
             fprintf(stderr, "usage: %s [options] <inputfile >outputfile\n"
-                            "version 2.4d  Copyright (c) 2002-2015 Jari Ruusu, 
(c) 2001 Dr Brian Gladman\n"
+                            "version 2.4e  Copyright (c) 2002-2017 Jari Ruusu, 
(c) 2001 Dr Brian Gladman\n"
                             "options:  -e aes128|aes192|aes256          =  set 
@@ -1,9 +1,9 @@
  *  aespipe.c
  *
- *  Written by Jari Ruusu, May 3 2015
+ *  Written by Jari Ruusu, September 10 2017
  *
key length\n"
                             "          -H sha256|sha384|sha512|rmd160   =  set 
password hash function\n"
                             "          -d         =  decrypt\n"